summaryrefslogtreecommitdiff
path: root/src/gui/gui-key.h
diff options
context:
space:
mode:
authorSébastien Helleu <flashcode@flashtux.org>2023-02-22 21:18:22 +0100
committerSébastien Helleu <flashcode@flashtux.org>2023-03-16 20:42:19 +0100
commit1f5c791c37957d8714fb0e7d6e962531790e259b (patch)
tree964d045319a87430d8ca117bba3a42daafbf8e22 /src/gui/gui-key.h
parent5b5ccb236f2f59cd792f0a2bda148d951b9156ed (diff)
downloadweechat-1f5c791c37957d8714fb0e7d6e962531790e259b.zip
core: use new key name in command `/key` and configuration file
Legacy keys are automatically converted to new names when loading configuration file `weechat.conf`. Examples: "ctrl-I" => "tab" "meta2-1;3A" => "meta-up" "meta2-Z" => "shift-tab" "meta-wmeta-meta2-A" => "meta-w,meta-up" "ctrl-Cb" => "ctrl-c,b"
Diffstat (limited to 'src/gui/gui-key.h')
-rw-r--r--src/gui/gui-key.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/gui-key.h b/src/gui/gui-key.h
index f49653bbe..8bcac6f64 100644
--- a/src/gui/gui-key.h
+++ b/src/gui/gui-key.h
@@ -54,8 +54,9 @@ enum t_gui_key_focus
struct t_gui_key
{
- char *key; /* raw key (eg: \001w, \001[[1;3D) */
- char *key_name; /* key name (eg: ctrl-w, meta-left) */
+ char *key; /* key name (eg: ctrl-w, meta-left) */
+ char **chunks; /* key chunks (split on comma) */
+ int chunks_count; /* number of chunks */
int area_type[2]; /* type of areas (for cursor/mouse) */
char *area_name[2]; /* name of areas (for cursor/mouse) */
char *area_key; /* key after area (after ":") */
@@ -90,8 +91,7 @@ extern time_t gui_key_last_activity_time;
extern void gui_key_init ();
extern int gui_key_search_context (const char *context);
extern void gui_key_grab_init (int grab_command, const char *delay);
-extern char *gui_key_get_internal_code (const char *key);
-extern char *gui_key_expand_legacy (const char *key);
+extern char *gui_key_legacy_expand (const char *key);
extern int gui_key_expand (const char *key,
char **key_name, char **key_name_alias);
extern char *gui_key_legacy_to_alias (const char *key);